citation

# XMLRésuméLibrary: User Guide

break | Element Reference | city

## Name

citation — The name of a work being referenced

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `citation` element marks the title of a book, website, course, or other work.

### Parents

`citation` may be contained in these elements: `achievement`, `employer`, `institution`, `organization`, `para`, `project`, `skill`

## See Also

`pub`.

## Examples

    <achievement>
      Increased earnings 341%, thereby landing Acme Widgets on <citation>Fortune
      Magazine</citation>'s Fortune 500 list.
    </achievement>

    <para>
      More information on the AHTM system is published in <citation>Developing
      Today</citation> at <url>http://www.dtoday.bob/tips.html</url>.
    </para>

break | Element Reference | city